import logging
import os
import serial

import config
import platforms
from base_detector import BaseDetector


class GPIOUARTDetector(BaseDetector):

    PORT_PATH_BASE = "/dev/tty"

    def __init__(self, app):
        self.app = app
        self.port_paths = config.get_settings().get('gpio_uart', {}).get('ports', [])
        self.printerid_dict_template = {'VID': 'UART', 'PID': '0PIN'}
        self.logger = logging.getLogger(self.__class__.__name__)

    def get_printers_list(self):
        # this is a one shot detector, that will be updated only ones per run of application
        printers = []
        if not self.app or not self.app.gpio_interface and platforms.PLATFORM == "rpi":
            for port_path in self.port_paths:
                if os.path.exists(port_path):
                    printerid_dict = {}
                    printerid_dict.update(self.printerid_dict_template)
                    printerid_dict['SNR'] = port_path.replace(self.PORT_PATH_BASE, "")
                    printerid_dict['COM'] = port_path
                    if printerid_dict not in printers:
                        printers.append(printerid_dict)
        return printers


if __name__ == "__main__":
    ud = GPIOUARTDetector(None)
    print(ud.get_printers_list())
